==> nextcloud-app-calendar-1%3A1.7.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/cy_GB.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Calendr",
    "%s has published the calendar »%s«" : "Mae %s wedi cyhoeddi’r calendr » %s«",
    "Hello," : "Helo,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Roeddem am eich hysbysu bod %s wedi cyhoeddi'r calendr » %s«.",
    "Open »%s«" : "Agor »%s«",
    "Cheers!" : "Hwyl!",
    "Recipient" : "Derbynnydd",
    "URL violates local access rules" : "Mae URL yn torri rheolau mynediad lleol",
    "The remote server did not give us access to the calendar (HTTP 404 error)" : "Nid yw'r gweinydd pell wedi rhoi mynediad inni i'r calendr (gwall HTTP 404)",
    "Too many redirects. Aborting ..." : "Gormod o ailgyfeiriadau. Cau ...",
    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "Nid yw'r gweinydd pell wedi rhoi mynediad inni i'r calendr (gwall HTTP {%s} )",
    "Error connecting to remote server" : "Gwall wrth gysylltu â'r gweinydd pell",
    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Gwall wrth ofyn am adnodd ar weinydd pell. Gall hyn fod yn gysylltiedig â chamgymhariad tystysgrif",
    "Error requesting resource on remote server" : "Gwall wrth ofyn am adnodd ar weinydd pell",
    "Individual" : "Unigolyn",
    "Group" : "Grŵp",
    "Resource" : "Adnodd",
    "Room" : "Ystafell",
    "Unknown" : "Anhysbys",
    "Required" : "Angen",
    "Optional" : "Dewisol",
    "Does not attend" : "Ddim yn mynychu",
    "{name} ({email})" : "{name} ({email})",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Rydych mewn cylch amser anhysbys ({tz}), yn disgyn nôl i UTC",
    "Please create a calendar first." : "Crëwch galendr yn gyntaf.",
    "New event" : "Digwyddiad newydd",
    "CalDAV address for clients" : "Cyfeiriad CalDAV ar gyfer cleientiaid",
    "Some events in this calendar are broken. Please check the JS console for more info." : "Mae rhai digwyddiadau yn y calendr hwn wedi torri. Gwiriwch y consol JS am ragor o wybodaeth.",
    "Share Calendar" : "Rhannu Calendr",
    "Shared" : "Rhannwyd",
    "Could not save WebCal-calendar" : "Methu cadw calendr WebCal",
    "WebDAV address for subscriptions" : "Cyfeiriad WebDAV ar gyfer tanysgrifiadau",
    "Email sent." : "Anfonwyd yr e-bost.",
    "Could not send your email." : "Methu anfon eich e-bost.",
    "group" : "grŵp",
    "circle" : "cylch",
    "Details" : "Manylion",
    "Attendees" : "Mynychwyr",
    "Reminders" : "Nodau atgoffa",
    "Repeating" : "Yn ailadrodd",
    "When shared show full event" : "Pan wedi ei rannu, yn dangos y digwyddiad llawn",
    "When shared show only busy" : "Pan wedi ei rannu, yn dangos dim ond prysur",
    "When shared hide this event" : "Pan wedi ei rannu, yn cuddio'r digwyddiad hwn",
    "Confirmed" : "Cadarnhawyd",
    "Tentative" : "I'w gadarnhau",
    "Cancelled" : "Diddymwyd",
    "Please add a title." : "Ychwanegwch deitl.",
    "Please select a calendar." : "Dewiswch galendr.",
    "The event can not end before it starts." : "Nid yw'r digwyddiad yn gallu gorffen cyn dechrau.",
    "Global" : "Eang",
    "None" : "Dim",
    "Every day" : "Pob dydd",
    "Every week" : "Pob wythnos",
    "Every month" : "Pob mis",
    "Every year" : "Pob blwyddyn",
    "never" : "byth",
    "after" : "wedi",
    "Automatic ({timezone})" : "Awtomatig  ({timezone})",
    "How about getting started by importing some calendars?" : "Beth am gychwyn trwy fewnforio rhai calendrau?",
    "At time of event" : "Adeg y digwyddiad",
    "5 minutes before" : "5  munud cynt",
    "10 minutes before" : "10 munud cynt",
    "15 minutes before" : "15 munud cynt",
    "30 minutes before" : "30 munud cynt",
    "1 hour before" : "1 awr cynt",
    "2 hours before" : "2 awr cynt",
    "Custom" : "Cyfaddas",
    "Audio" : "Sain",
    "Email" : "E-bost",
    "Pop-up" : "Llamlen",
    "sec" : "eil",
    "min" : "mun",
    "hours" : "awr",
    "days" : "diwrnod",
    "week" : "wythnos",
    "before" : "cynt",
    "start" : "cychwyn",
    "end" : "gorffen",
    "Editing reminders of unknown type not supported." : "Nid yw golygu nodiadau atgoffa o fath anhysbys yn cael eu cefnogi.",
    "Week {number} of {year}" : "Wythnos {number} o {year}",
    "Successfully imported {imported} objects" : "Gwrthrychau wedi'u mewnforio  {imported} yn llwyddiannus",
    "Imported {imported} out of {all}, skipped one duplicate" : "Mewnforio {imported} allan o {all}, hepgor un dyblyg",
    "Imported {imported} out of {all}, one failure" : "Mewnforio {imported} allan o {all}, un methiant",
    "Imported {imported} out of {all}, {errors} failures" : "Mewnforio {imported} allan o {all}, {errors} methiannau",
    "Imported {imported} out of {all}, skipped {duplicates} duplicates" : "Mewnforio {errors} allan o {all}, hepgor {duplicates} dyblyg",
    "Imported {imported} out of {all}, {errors} failures, skipped {duplicates} duplicates" : "Mewnforio {imported} allan o {all}, {errors} methiannau, hepgor {duplicates} dyblyg",
    "Audio alarm {time} before the event starts" : "Larwm sain {time} cyn i'r digwyddiad ddechrau",
    "Pop-up {time} before the event starts" : "Llamlen {time} cyn i'r digwyddiad ddechrau",
    "Email {time} before the event starts" : "E-bost {time} cyn i'r digwyddiad ddechrau",
    "None {time} before the event starts" : "Dim {time} cyn i'r digwyddiad ddechrau",
    "{type} {time} before the event starts" : "{type} {time} cyn i'r digwyddiad ddechrau",
    "Audio alarm {time} before the event ends" : "Larwm sain {time} cyn i'r digwyddiad ddod i ben",
    "Pop-up {time} before the event ends" : "Llamlen {time} cyn i'r digwyddiad ddod i ben",
    "Email {time} before the event ends" : "E-bostiwch {time} cyn i'r digwyddiad ddod i ben",
    "None {time} before the event ends" : "Dim {time} cyn i'r digwyddiad ddod i ben",
    "{type} {time} before the event ends" : "{type} {time} cyn i'r digwyddiad ddod i ben",
    "Audio alarm {time} after the event starts" : "Larwm sain {time} ar ôl i'r digwyddiad ddechrau",
    "Pop-up {time} after the event starts" : "Llamlen {time} ar ôl i'r digwyddiad ddechrau",
    "Email {time} after the event starts" : "E-bostio {time} ar ôl i'r digwyddiad ddechrau",
    "None {time} after the event starts" : "Dim {time} ar ôl i'r digwyddiad ddechrau",
    "{type} {time} after the event starts" : "{type} {time} ar ôl i'r digwyddiad ddechrau",
    "Audio alarm {time} after the event ends" : "Larwm sain {time} ar ôl i'r digwyddiad ddod i ben",
    "Pop-up {time} after the event ends" : "Llamlen {time} ar ôl i'r digwyddiad ddod i ben",
    "Email {time} after the event ends" : "E-bostio {time} ar ôl i'r digwyddiad ddod i ben",
    "None {time} after the event ends" : "Dim {time} ar ôl i'r digwyddiad ddod i ben",
    "{type} {time} after the event ends" : "{type} {time} ar ôl i'r digwyddiad ddod i ben",
    "Audio alarm at the event's start" : "Sain larwm ar ddechrau'r digwyddiad",
    "Pop-up at the event's start" : "Llamlen ar ddechrau'r digwyddiad",
    "Email at the event's start" : "E-bost ar ddechrau'r digwyddiad",
    "None at the event's start" : "Dim ar ddechrau'r digwyddiad",
    "{type} at the event's start" : "{type} ar ddechrau'r digwyddiad",
    "Audio alarm at the event's end" : "Sain larwm ar ddiwedd y digwyddiad",
    "Pop-up at the event's end" : "Llamlen ar ddiwedd y digwyddiad",
    "Email at the event's end" : "E-bost ar ddiwedd y digwyddiad",
    "None at the event's end" : "Dim ar ddiwedd y digwyddiad",
    "{type} at the event's end" : "{type} ar ddiwedd y digwyddiad",
    "Audio alarm at {time}" : "Sain larwm am {time}",
    "Pop-up at {time}" : "Llamlen am {time}",
    "Email at {time}" : "E-bost am {time}",
    "None at {time}" : "Dim am {time}",
    "{type} at {time}" : "{type} ar {time}",
    "{calendar} shared by {owner}" : "{calendar} wedi'i rannu gan {owner}",
    "Please enter a valid WebCal-URL" : "Rhowch WebCal-URL dilys",
    "Severe error in webcal proxy. Please contact administrator for more information." : "Gwall difrifol yn y dirprwy webcal. Cysylltwch â'r gweinyddwr i gael mwy o wybodaeth.",
    "A Calendar app for Nextcloud" : "Ap Calendr ar gyfer Nextcloud",
    "The Calendar app is a user interface for Nextcloud's CalDAV server. Easily sync events from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Contacts - more to come.\n* 🌐 **WebCal Support!** Want to see your favorite team’s matchdays in your calendar? No problem!\n* 🙋 **Attendees!** Invite people to your events.\n* 🙈 **We’re not reinventing the wheel!** Based on the great [davclient.js](https://github.com/evert/davclient.js), [ical.js](https://github.com/mozilla-comm/ical.js) and [fullcalendar](https://github.com/fullcalendar/fullcalendar) libraries." : "Mae'r app Calendr yn rhyngwyneb defnyddiwr ar gyfer gweinydd CalDAV Nextcloud. Gallwch yn hawdd gysoni digwyddiadau o wahanol ddyfeisiau â'ch Nextcloud a'u golygu ar-lein.\n\n* 🚀 ** Integreiddio ag apiau Nextcloud eraill! ** Cysylltiadau ar hyn o bryd - mwy i ddod.\n* 🌐 ** Cefnogaeth WebCal! ** Am weld dyddiau gemau eich hoff dîm yn eich calendr? Dim problem!\n* 🙋 ** Mynychwyr! ** Gwahoddwch bobl i'ch digwyddiadau.\n* 🙈 ** Nid ydym yn ailddyfeisio'r olwyn! ** Yn seiliedig ar llyfrgelloedd gwych [davclient.js](https://github.com/evert/davclient.js), [ical.js](https://github.com/mozilla-comm/ical.js) a [fullcalendar](https://github.com/fullcalendar/fullcalendar).",
    "Title of the Event" : "Teitl y digwyddiad",
    "Starts" : "Yn cychwyn",
    "Ends" : "Yn gorffen",
    "All day Event" : "Digwyddiad trwy'r dydd",
    "Delete" : "Dileu",
    "Cancel" : "Diddymu",
    "More ..." : "_Rhagor ...",
    "Create" : "Creu",
    "Update" : "Diweddaru",
    "Close" : "Cau",
    "Location" : "Lleoliad",
    "Description" : "Disgrifiad",
    "Event status" : "Statws digwyddiad",
    "Visibility when sharing" : "Gwelededd wrth rannu",
    "Export" : "Allforio",
    "%s has published the calendar %s" : "Mae %s wedi cyhoeddi’r calendr %s",
    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "Roeddem am eich hysbysu bod %s wedi cyhoeddi'r calendr {boldstart} %s {boldend}.",
    "Click here to access it" : "Cliciwch yma i gael mynediad iddo",
    "We wanted to inform you that %s has published the calendar %s." : "Roeddem am eich hysbysu bod %s wedi cyhoeddi'r calendr »%s.",
    "Click on the link below to access it" : "Cliciwch ar y ddolen isod i gael mynediad iddo",
    "Day" : "Diwrnod",
    "Week" : "Wythnos",
    "Month" : "Mis",
    "Today" : "Heddiw",
    "More" : "Rhagor",
    "Edit" : "Golygu",
    "Link" : "Dolen",
    "iCal link" : "Dolen iCal",
    "Download" : "Llwytho i lawr",
    "Share with users, groups or circles" : "Rhannwch gyda defnyddwyr, grwpiau neu gylchoedd",
    "can edit" : "yn gallu golygu",
    "Share link" : "Rhannu dolen",
    "Public access" : "Mynediad cyhoeddus",
    "Email link to person" : "E-bostio dolen at berson",
    "Send" : "Anfon",
    "New Calendar" : "Calendr Newydd",
    "Name" : "Enw",
    "New Subscription" : "Tanysgrifiad Newydd",
    "Go back" : "Nôl",
    "Go forward" : "Ymlaen",
    "Calendar does not exist" : "Nid yw'r calendr yn bodoli",
    "Maybe you got a wrong link or the calendar was unshared?" : "Efallai bod gennych ddolen anghywir neu fod y calendr heb ei rannu?",
    "Edit event" : "Golygu digwyddiad",
    "Delete Event" : "Dileu Digwyddiad",
    "Save Event" : "Cadw Digwyddiad",
    "Time" : "Amser",
    "Type" : "Math",
    "Relative" : "Perthynas",
    "Absolute" : "Absoliwt",
    "Repeat" : "Ailadrodd",
    "times every" : "gwaith bob",
    "Email reminders have not been implemented in the CalDAV server yet, so none will be sent." : "Nid yw nodau atgoffa e-bost wedi'u gweithredu yn y gweinydd CalDAV eto, felly ni fydd unrhyw un yn cael ei anfon.",
    "Add" : "Ychwanegu",
    "Email address of attendee" : "Cyfeiriad e-bost y mynychwr",
    "Please add your email address in the personal settings in order to add attendees." : "Ychwanegwch eich cyfeiriad e-bost yn y gosodiadau personol er mwyn ychwanegu mynychwyr.",
    "from" : "oddi wrth",
    "to" : "at",
    "This event's repeating rule is not supported yet." : "Nid yw'r rheol ailadroddus y digwyddiad yn cael ei gynnal eto.",
    "Support for advanced rules will be added with subsequent updates." : "Bydd cefnogaeth ar gyfer rheolau uwch yn cael ei ychwanegu mewn diweddariadau dilynol.",
    "Reset repeating rule" : "Ailosod rheol ailadroddus",
    "Repeat every ..." : "Ailadrodd bob ...",
    "end repeat ..." : "gorffen ailadrodd ...",
    "times" : "gwaith",
    "Import Calendars" : "Mewnforio Calendrau",
    "Import canceled" : "Mewnforio wedi'i ddiddymu",
    "Analyzing calendar" : "Dadansoddi'r calendr",
    "The file contains objects incompatible with the selected calendar" : "Mae'r ffeil yn cynnwys gwrthrychau sy'n anghydnaws â'r calendr a ddewiswyd",
    "New calendar" : "Calendr newydd",
    "File is empty" : "Mae'r ffeil yn wag",
    "File could not be parsed" : "Nid oedd modd didoli'r ffeil",
    "Import scheduled" : "Mewnforio wedi'i amserlennu",
    "%s shared the calendar <strong>%s</strong> with you" : "Rhannodd %s y calendr <strong>%s</strong> gyda chi",
    "Embed" : "Mewnblannu",
    "Iframe to integrate" : "Iframe i'w integreiddio",
    "Publish URL" : "Cyhoeddi'r URL",
    "Settings & import" : "Gosodiadau a mewnforio",
    "Import calendar" : "Mewnforio'r calendr",
    "No Calendars selected for import" : "Dim Calendrau wedi'u dewis i'w mewnforio",
    "Skip simple event editor" : "Hepgor y golygydd digwyddiadau syml",
    "Show week numbers" : "Dangos rhifau wythnosau",
    "Timezone" : "Cylch amser",
    "Primary CalDAV address" : "Cyfeiriad CalDAV cynradd",
    "iOS/macOS CalDAV address" : "Cyfeiriad CalDAV iOS/macOS",
    "Subscribe" : "Tanysgrifio"
},
"nplurals=4; plural=(n==1) ? 0 : (n==2) ? 1 : (n != 8 && n != 11) ? 2 : 3;");

==> nextcloud-app-calendar-1%3A2.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/cy_GB.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Calendr",
    "%s has published the calendar »%s«" : "Mae %s wedi cyhoeddi’r calendr » %s«",
    "Hello," : "Helo,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Roeddem am eich hysbysu bod %s wedi cyhoeddi'r calendr » %s«.",
    "Open »%s«" : "Agor »%s«",
    "Cheers!" : "Hwyl!",
    "A Calendar app for Nextcloud" : "Ap Calendr ar gyfer Nextcloud",
    "Today" : "Heddiw",
    "Day" : "Diwrnod",
    "Week" : "Wythnos",
    "Month" : "Mis",
    "Download" : "Llwytho i lawr",
    "Delete" : "Dileu",
    "Share link" : "Rhannu dolen",
    "Share with users or groups" : "Rhannwch gyda defnyddwyr neu grwpiau",
    "No users or groups" : "Dim defnyddwyr na grwpiau",
    "can edit" : "yn gallu golygu",
    "New calendar" : "Calendr newydd",
    "Cancel" : "Diddymu",
    "Show week numbers" : "Dangos rhifau wythnosau",
    "Settings & import" : "Gosodiadau a mewnforio",
    "Email" : "E-bost",
    "Unknown" : "Anhysbys",
    "from" : "oddi wrth",
    "to" : "at",
    "never" : "byth",
    "after" : "wedi",
    "Repeat" : "Ailadrodd",
    "Monday" : "Llun",
    "More" : "Rhagor",
    "Save" : "Cadw",
    "Update" : "Diweddaru",
    "Select Date" : "Dewis Dyddiad",
    "Personal" : "Personol",
    "Details" : "Manylion",
    "Attendees" : "Mynychwyr",
    "Reminders" : "Nodau atgoffa",
    "Activity" : "Gweithred",
    "Close" : "Cau",
    "Anniversary" : "Dathliad",
    "Week {number} of {year}" : "Wythnos {number} o {year}",
    "When shared show full event" : "Pan wedi ei rannu, yn dangos y digwyddiad llawn",
    "When shared show only busy" : "Pan wedi ei rannu, yn dangos dim ond prysur",
    "When shared hide this event" : "Pan wedi ei rannu, yn cuddio'r digwyddiad hwn",
    "Location" : "Lleoliad",
    "Description" : "Disgrifiad",
    "Confirmed" : "Cadarnhawyd",
    "Tentative" : "I'w gadarnhau",
    "Cancelled" : "Diddymwyd",
    "Mail" : "E-bost",
    "Play" : "Chwarae",
    "Global" : "Eang"
},
"nplurals=4; plural=(n==1) ? 0 : (n==2) ? 1 : (n != 8 && n != 11) ? 2 : 3;");
